@@ -355,17 +355,26 @@ class OpenEuler():
 
 
     def get_openEuler_core_rpm_list(self,os_version,os_arch):
-        core_src_list=self.get_core_src_list()
-        core_rpm_list=[]
-        os_rpm2src=self.get_openEuler_os_rpm2src(os_version,os_arch)
-        for rpm_name,src_name in os_rpm2src.items():
-            if src_name in core_src_list and rpm_name not in core_rpm_list:
-                core_rpm_list.append(rpm_name)
-        return core_rpm_list
+        rpm2src=self.get_openEuler_core_rpm2src(os_version,os_arch)
+        return rpm2src.keys()
 
+    def get_openEuler_core_rpm2src(self,os_version,os_arch):
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_Core.json"
+        rpm2src_data=dict({})
+        try:
+            with open(rpm2src_file_path, "r",encoding="utf-8") as f:
+                rpm2src_data = json.load(f)
+        except FileNotFoundError:
+            log.error(f"未找到 {rpm2src_file_path} 文件")
+        except json.JSONDecodeError:
+            log.error(f"{rpm2src_file_path} 文件格式错误")
+        except Exception as e:
+            log.error(f"{rpm2src_file_path} 文件读取错误: {str(e)}")
+        finally:
+            return rpm2src_data
 
     def get_openEuler_os_rpm2src(self,os_version,os_arch):
-        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_os.json"
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_OS.json"
         rpm2src_data=dict({})
         try:
             with open(rpm2src_file_path, "r",encoding="utf-8") as f:
@@ -395,7 +404,7 @@ class OpenEuler():
             return rpm2src_data
 
     def get_openEuler_everything_rpm2src(self,os_version,os_arch):
-        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_everything.json"
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_Everything.json"
         rpm2src_data=dict({})
         try:
             with open(rpm2src_file_path, "r",encoding="utf-8") as f:
@@ -410,7 +419,7 @@ class OpenEuler():
             return rpm2src_data
 
     def get_openEuler_epol_rpm2src(self,os_version,os_arch):
-        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_epol.json"
+        rpm2src_file_path=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_EPOL.json"
         rpm2src_data=dict({})
         try:
             with open(rpm2src_file_path, "r",encoding="utf-8") as f:
@@ -498,6 +507,18 @@ if __name__ == "__main__":
     #         rs3.append(elem)
     # print(f"total {len(rs)} rpms and {len(rs3)} same with x86_64")
 
+    # os_version="24.03-LTS"
+    # os_arch="x86_64"
+    # oe=OpenEuler()
+    # core_src_list=oe.get_core_src_list()
+    # file_name=Path(__file__).resolve().parent / "pkg_info" / f"openEuler_{os_version}_{os_arch}_Core.json"
+    # everything_rpm2src=oe.get_openEuler_everything_rpm2src(os_version,os_arch)
+    # core_rpm2src=dict({})
+    # for rpm,src in everything_rpm2src.items():
+    #     if src in core_src_list:
+    #         core_rpm2src[rpm]=src
+    # with open(file_name, "w", encoding="utf-8") as f:
+    #     json.dump(core_rpm2src, f, ensure_ascii=False, indent=4)
 
     pass
 
